<?php
/**
 * alexradar Theme Theme Customizer
 *
 * @package alexradar
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */


function alexradar_customizer_option( $wp_customize ) {

	$wp_customize->add_setting(
		'header_bg_color',
		array(
			'default'     => '#fff',
			'sanitize_callback' => 'sanitize_hex_color'
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'bg_color',
			array(
				'label'      => __( 'Header Background Color', 'alexradar' ),
				'section'    => 'colors',
				'settings'   => 'header_bg_color',
				'priority'   =>'2'
			)
		)
	);


	$wp_customize->add_setting('copyright_txt', array(
		'default' => '',
		'transport' => 'postMessage',
		'sanitize_callback' => 'wp_filter_nohtml_kses'
	));

	$wp_customize->add_control('footer_copyright', array(
		'label'      => __('Footer Copyright Text', 'alexradar'),
		'section'    => 'alexradar_footer_section',
		'settings'   => 'copyright_txt',
        'type'       =>'textarea'
	));

}
add_action( 'customize_register', 'alexradar_customizer_option' );



function alexradar_customize_register( $wp_customize ) {

	$wp_customize->remove_section( 'header_image' );

	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'blogname', array(
			'selector'        => '.site-title a',
			'render_callback' => 'alexradar_customize_partial_blogname',
		) );
		$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
			'selector'        => '.site-description',
			'render_callback' => 'alexradar_customize_partial_blogdescription',
		) );
	}
}
add_action( 'customize_register', 'alexradar_customize_register' );

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function alexradar_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function alexradar_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function alexradar_customize_preview_js() {
	wp_enqueue_script( 'alexradar-customizer', get_template_directory_uri() . '/assets/js/customizer.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'alexradar_customize_preview_js' );

function alexradar_customizer_css() {
	?>
	<style type="text/css">
		.header-section { background-color: <?php echo esc_html(get_theme_mod( 'header_bg_color' )); ?>; }
	</style>
	<?php
}
add_action( 'wp_head', 'alexradar_customizer_css' );